@@ -836,21 +836,22 @@ class recset(Generic[T]):
             self.__dfrows:pd.DataFrame = self.__dfrows[dfw]
             
             # rows初期化
+            rowsTempDict = {}
             rowsTemp = []
             
             # __rowsをフィルタする
-            foundRow = False
-            for index, item in self.__dfrows.iterrows():
-                for row in self.__rows:
-                    for key in self.__getPrimaryKeys():
-                        if getattr(row, key) == item[key]:
-                            foundRow = True
-                            continue
-                        else:
-                            foundRow = False
-                    if foundRow:
-                        rowsTemp.append(row)
-                        break
+            for row in self.__rows:
+                keyValue = ''
+                for key in self.__getPrimaryKeys():
+                    keyValue += getattr(row, key)
+                rowsTempDict[keyValue] = row
+            for index,item in self.__dfrows.iterrows():
+                keyValue = ''
+                for key in self.__getPrimaryKeys():
+                    keyValue += item[key]
+                if keyValue in rowsTempDict:
+                    rowsTemp.append(rowsTempDict[keyValue])
+            
             self.__rows = rowsTemp
 
             # __dfrowsを再構築する
